@@ -1,29 +1,18 @@
-/***************************************************************************
- *   This file is part of the KDE project                                  *
- *   Copyright 2007 Will Stephenson <wstephenson@kde.org>                  *
- *   Copyright (C) 2009 Ben Cooksley <bcooksley@kde.org>                   *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA          *
- ***************************************************************************/
+/*
+ *   This file is part of the KDE project
+ *   SPDX-FileCopyrightText: 2007 Will Stephenson <wstephenson@kde.org>
+ *   SPDX-FileCopyrightText: 2009 Ben Cooksley <bcooksley@kde.org>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #ifndef MENUITEM_H
 #define MENUITEM_H
 
 #include <KService>
 
+#include "systemsettingsview_export.h"
+
 class QString;
 class KCModuleInfo;
 template<typename T> class QList;
@@ -45,7 +34,7 @@ template<typename T> class QList;
  * @author Ben Cooksley <bcooksley@kde.org>
  * @author Will Stephenson <wstephenson@kde.org>
  */
-class MenuItem
+class SYSTEMSETTINGSVIEW_EXPORT MenuItem
 {
 public:
     /**
@@ -161,6 +150,14 @@ public:
 
     void updateDefaultIndicator();
 
+    void setDefaultIndicator(bool defaultIndicator);
+    
+    /**
+     * If true this is the main module of this category and should appear in a more prominent way compared to the others
+     */
+    bool isCategoryOwner() const;
+    void setCategoryOwner(bool owner);
+
 private:
     class Private;
     Private *const d;
