@@ -1,21 +1,8 @@
-/**************************************************************************
- * Copyright (C) 2009 by Ben Cooksley <bcooksley@kde.org>                 *
- *                                                                        *
- * This program is free software; you can redistribute it and/or          *
- * modify it under the terms of the GNU General Public License            *
- * as published by the Free Software Foundation; either version 2         *
- * of the License, or (at your option) any later version.                 *
- *                                                                        *
- * This program is distributed in the hope that it will be useful,        *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- * GNU General Public License for more details.                           *
- *                                                                        *
- * You should have received a copy of the GNU General Public License      *
- * along with this program; if not, write to the Free Software            *
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA          *
- * 02110-1301, USA.                                                       *
- ***************************************************************************/
+/*
+ * SPDX-FileCopyrightText: 2009 Ben Cooksley <bcooksley@kde.org>
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #include "IconMode.h"
 #include "CategorizedView.h"
@@ -181,7 +168,7 @@ void IconMode::changeModuleWithArgs(const QModelIndex &activeModule, const QStri
 void IconMode::moduleLoaded()
 {
     d->backAction->setEnabled(true);
-    emit changeToolBarItems(BaseMode::NoItems);
+    Q_EMIT changeToolBarItems(BaseMode::NoItems);
 }
 
 void IconMode::backToOverview()
@@ -190,8 +177,8 @@ void IconMode::backToOverview()
         d->mainWidget->setCurrentWidget(d->categoryView);
         d->moduleView->closeModules();
         d->backAction->setEnabled(false);
-        emit changeToolBarItems(BaseMode::Search | BaseMode::Configure | BaseMode::Quit);
-        emit viewChanged(false);
+        Q_EMIT changeToolBarItems(BaseMode::Search | BaseMode::Configure | BaseMode::Quit);
+        Q_EMIT viewChanged(false);
     }
 }
 
@@ -220,7 +207,7 @@ void IconMode::initWidget()
     d->mainWidget->addWidget(d->categoryView);
     d->mainWidget->addWidget(d->moduleView);
     d->mainWidget->setCurrentWidget(d->categoryView);
-    emit changeToolBarItems(BaseMode::Search | BaseMode::Configure | BaseMode::Quit);
+    Q_EMIT changeToolBarItems(BaseMode::Search | BaseMode::Configure | BaseMode::Quit);
     d->mainWidget->installEventFilter(this);
 
     if (!startupModule().isEmpty()) {
@@ -244,7 +231,7 @@ void IconMode::reloadStartupModule()
 bool IconMode::eventFilter(QObject *watched, QEvent *event)
 {
     if (watched == d->mainWidget && event->type() == QEvent::Show) {
-        emit changeToolBarItems(BaseMode::Search | BaseMode::Configure | BaseMode::Quit);
+        Q_EMIT changeToolBarItems(BaseMode::Search | BaseMode::Configure | BaseMode::Quit);
     }
     return BaseMode::eventFilter(watched, event);
 }
